Skip to content

Releases: openconfig/ygnmi

v0.11.1

08 Jan 18:37
7782388
Compare
Choose a tag to compare

What's Changed

  • Support Map() API for ygnmi.SetBatch operations. by @wenovus in #142

Full Changelog: v0.11.0...v0.11.1

v0.11.0

06 Dec 21:01
c4957ab
Compare
Choose a tag to compare

Breaking Changes

  • Names within RequestValues were changed to be clearer:
diff --git a/ygnmi/context.go b/ygnmi/context.go
index 6650736..bc668fd 100644
--- a/ygnmi/context.go
+++ b/ygnmi/context.go
@@ -20,35 +20,26 @@ import (

 // RequestValues contains request-scoped values for ygnmi queries.
 type RequestValues struct {
-       // CompressedConfigQuery is a key type that means that the query is
-       // uninterested in /state paths.
-       CompressedConfigQuery bool
-       // CompressedStateQuery is a key type that means that the query is
-       // uninterested in /config paths.
-       CompressedStateQuery bool
+       // StateFiltered is a key type that means that the query is
+       // uninterested in /state paths and will filter them out.
+       StateFiltered bool
+       // ConfigFiltered is a key type that means that the query is
+       // uninterested in /config paths and will filter them out.
+       ConfigFiltered bool
 }

What's Changed

Full Changelog: v0.10.2...v0.11.0

v0.10.2

04 Dec 19:33
e5dde15
Compare
Choose a tag to compare

What's Changed

  • Factor out gnmitestutil to allow dependency on ygnmi package. by @wenovus in #138
  • Context RequestValues for ygnmi queries by @wenovus in #139

Full Changelog: v0.10.1...v0.10.2

v0.10.1

11 Nov 00:45
1c8deb5
Compare
Choose a tag to compare

What's Changed

Full Changelog: v0.10.0...v0.10.1

v0.10.0

09 Nov 01:20
af2a64f
Compare
Choose a tag to compare

Breaking Changes

  • Add hidden -typedef_enum_with_defmod flag by @wenovus in #119
    • All current users are likely to experience a breaking change due to the addition of the hidden flag -typedef_enum_with_defmod which is by default "true". If this broke your code, you can either 1) set this flag to false, or 2) convert existing code to the supported enumeration names, which is named using the defining module of each enum.
    • NOTE: This flag is planned to be removed by ygnmi@v1.0.0

What's Changed

Full Changelog: v0.9.0...v0.10.0

v0.9.0

24 Oct 22:11
c72751e
Compare
Choose a tag to compare

Breaking Changes

  • ygnmi.Batch.AddPaths now takes in query types rather than PathStruct types. Fixing this generally involves removing the .PathStruct() method call, or adding the .Config() or .State() method calls in the path call chain.

What's Changed

Full Changelog: v0.8.11...v0.9.0

v0.8.11

16 Oct 20:54
a0ee6ed
Compare
Choose a tag to compare

What's Changed

Full Changelog: v0.8.10...v0.8.11

v0.8.10

13 Sep 16:14
4b6649a
Compare
Choose a tag to compare

What's Changed

Full Changelog: v0.8.9...v0.8.10

v0.8.9

07 Sep 20:14
d36b514
Compare
Choose a tag to compare

What's Changed

Full Changelog: v0.8.8...v0.8.9

v0.8.8

29 Aug 16:20
f1bc953
Compare
Choose a tag to compare

What's Changed

Full Changelog: v0.8.7...v0.8.8